const utils = require('./utils');
const config = require('../config');
const vueLoaderConfig = require('./vue-loader.conf');
const resolveConfig = require('./resolve.conf');
// const webpack = require('webpack');
const merge = require('webpack-merge');

let resolve = resolveConfig.resolve;

// noinspection NpmUsedModulesInstalled
let webpackConfig = {
    entry     : resolveConfig.resolve('src/publish.js'),
    output    : {
        path          : config.build.buildOutputRoot,
        // chunkFilename : "js/[name].[chunkhash:7].js",
        filename      : 'publish.js',
        publicPath    : config.build.assetsPublicPath,
        libraryTarget : 'umd',
    },
    resolve   : resolveConfig.config,
    externals : {
        moment       : 'moment',
        // "element-ui" : "ElementUI",
        "vue"        : "vue",
    },
    module    : {
        rules : [
            {
                test    : /\.(js|vue)$/,
                loader  : 'eslint-loader',
                enforce : 'pre',
                include : [resolve('src'), resolve('test')],
                options : {
                    formatter : require('eslint-friendly-formatter'),
                },
            },
            {
                test    : /\.vue$/,
                loader  : 'vue-loader',
                options : vueLoaderConfig,
            },
            {
                test    : /\.js$/,
                loader  : 'babel-loader',
                include : [resolve('src'), resolve('test'), resolve('slimvue.js')],
            },
            {
                test    : /\.(png|jpe?g|gif|svg)(\?.*)?$/,
                loader  : 'url-loader',
                options : {
                    limit : 1000000,
                    name  : utils.assetsPath('img/[name].[hash:7].[ext]'),
                },
            },
            {
                test    : /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
                loader  : 'url-loader',
                options : {
                    limit : 10000,
                    name  : utils.assetsPath('media/[name].[hash:7].[ext]'),
                },
            },
            {
                test    : /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
                loader  : 'url-loader',
                options : {
                    limit : 10000,
                    name  : utils.assetsPath('fonts/[name].[hash:7].[ext]'),
                },
            },
        ],
    },
    plugins   : ([]).concat(
        require('./plugins/define-plugin'),
    ),
};

webpackConfig = merge(webpackConfig, {
    module  : {
        rules : utils.styleLoaders({
            sourceMap : config.build.cssSourceMap,
            extract   : true,
        }),
    },
    devtool : config.build.cssSourceMap ? '#source-map' : false,
    plugins : ([]).concat(
        require('./plugins/clean-plugin'),
        // require('./plugins/optimize-plugin')
    ),
});
module.exports = webpackConfig;
